@@ -13,8 +13,6 @@
 import os
 import warnings
 
-from positional import positional
-
 from keystoneauth1 import session
 
 
@@ -87,11 +85,10 @@ class Adapter(object):
     client_name = None
     client_version = None
 
-    @positional()
     def __init__(self, session, service_type=None, service_name=None,
                  interface=None, region_name=None, endpoint_override=None,
                  version=None, auth=None, user_agent=None,
-                 connect_retries=None, logger=None, allow={},
+                 connect_retries=None, logger=None, allow=None,
                  additional_headers=None, client_name=None,
                  client_version=None, allow_version_hack=None,
                  global_request_id=None,
@@ -117,7 +114,7 @@ class Adapter(object):
         self.auth = auth
         self.connect_retries = connect_retries
         self.logger = logger
-        self.allow = allow
+        self.allow = allow or {}
         self.additional_headers = additional_headers or {}
         self.allow_version_hack = allow_version_hack
         self.min_version = min_version
@@ -246,6 +243,25 @@ class Adapter(object):
 
         return self.session.get_endpoint_data(auth or self.auth, **kwargs)
 
+    def get_api_major_version(self, auth=None, **kwargs):
+        """Get the major API version as provided by the auth plugin.
+
+        :param auth: The auth plugin to use for token. Overrides the plugin on
+                     the session. (optional)
+        :type auth: keystoneauth1.plugin.BaseAuthPlugin
+
+        :raises keystoneauth1.exceptions.auth_plugins.MissingAuthPlugin: if a
+            plugin is not available.
+
+        :return: The major version of the API of the service discovered.
+        :rtype: tuple or None
+        """
+        self._set_endpoint_filter_kwargs(kwargs)
+        if self.endpoint_override:
+            kwargs['endpoint_override'] = self.endpoint_override
+
+        return self.session.get_api_major_version(auth or self.auth, **kwargs)
+
     def invalidate(self, auth=None):
         """Invalidate an authentication plugin."""
         return self.session.invalidate(auth or self.auth)
